@@ -171,11 +171,11 @@ class Text:
 
 
 class PhraseValidity(Enum):
-    UNKNOWN = 1
-    VALID = 2
-    INVALID = 3
-    SPECIAL = 4
-    EMPTY = 5
+    UNKNOWN = 'UNKNOWN'
+    VALID = 'VALID'
+    INVALID = 'INVALID'
+    SPECIAL = 'SPECIAL'
+    EMPTY = 'EMPTY'
 
 
 class Phrase:
@@ -238,7 +238,7 @@ class Phrase:
         :return: Nothing
         """
         if not (isinstance(word, Word)):
-            raise Exception("Bad argument to add_word, expected a word instance")
+            raise Exception("Bad argument to add_word, expected a word instance, got %s" % (type(word)))
 
         self.words.append(word)
 
