@@ -1,9 +1,7 @@
 import xml.etree.ElementTree as ElementTree
 from xml.dom import minidom
 
-from typecraft_python.globals import STRICT_MODE
 from typecraft_python.exceptions.parsing import TypecraftParseException
-from typecraft_python.models import Text, Phrase, Word, Morpheme, GlobalTagSet, GlobalTag
 from typecraft_python.models import Text, Phrase, Word, Morpheme, GlobalTagSet, GlobalTag, PhraseValidity
 from typecraft_python.globals import *
 
@@ -543,7 +541,7 @@ class Parser:
     def convert_phrase_to_etree(root, phrase):
         assert isinstance(phrase, Phrase)
 
-        phrase_el = ElementTree.SubElement(root, 'phrase', {'valid': 'UNKNOWN'})
+        phrase_el = ElementTree.SubElement(root, 'phrase', {'valid': phrase.validity.value})
 
         ElementTree.SubElement(phrase_el, 'original').text = phrase.phrase
         ElementTree.SubElement(phrase_el, 'translation').text = phrase.translation
